@@ -2,10 +2,22 @@
 #
 # fitqtl.R
 #
-# copyright (c) 2002-8, Hao Wu and Karl W. Broman
-# last modified Dec, 2008
+# copyright (c) 2002-9, Hao Wu and Karl W. Broman
+# last modified Feb, 2009
 # first written Apr, 2002
-# Licensed under the GNU General Public License version 2 (June, 1991)
+#
+#     This program is free software; you can redistribute it and/or
+#     modify it under the terms of the GNU General Public License, as
+#     published by the Free Software Foundation; either version 2 of
+#     the License, or (at your option) any later version. 
+# 
+#     This program is distributed in the hope that it will be useful,
+#     but without any warranty; without even the implied warranty of
+#     merchantability or fitness for a particular purpose.  See the
+#     GNU General Public License for more details.
+# 
+#     A copy of the GNU General Public License is available at
+#     http://www.r-project.org/Licenses/
 # 
 # Part of the R/qtl package
 # Contains: fitqtl, fitqtlengine, parseformula, summary.fitqtl,
@@ -864,7 +876,7 @@ print.summary.fitqtl <- function(x, ...)
   cat("Model formula:")
   w <- options("width")[[1]]
   printQTLformulanicely(attr(x, "formula"), "                   ", w+5, w)
-  cat("\n\n")
+  cat("\n")
   
   pval <- attr(x, "pvalues")
   if(is.null(pval) || pval)
