@@ -2,12 +2,23 @@
  * 
  * scanone_mr.c
  *
- * copyright (c) 2001-6, Karl W Broman, Johns Hopkins University
+ * copyright (c) 2001-6, Karl W Broman
  *
- * last modified Feb, 2006
+ * last modified Dec, 2006
  * first written Nov, 2001
  *
- * Licensed under the GNU General Public License version 2 (June, 1991)
+ *     This program is free software; you can redistribute it and/or
+ *     modify it under the terms of the GNU General Public License, as
+ *     published by the Free Software Foundation; either version 2 of
+ *     the License, or (at your option) any later version. 
+ * 
+ *     This program is distributed in the hope that it will be useful,
+ *     but without any warranty; without even the implied warranty of
+ *     merchantability or fitness for a particular purpose.  See the
+ *     GNU General Public License for more details.
+ * 
+ *     A copy of the GNU General Public License is available at
+ *     http://www.r-project.org/Licenses/
  *
  * C functions for the R/qtl package
  *
@@ -26,6 +37,7 @@
 #include <Rmath.h>
 #include <R_ext/PrtUtil.h>
 #include <R_ext/Applic.h>
+#include <R_ext/Utils.h>
 #include "util.h"
 #include "scanone_mr.h"
 #define TOL 1e-12
@@ -121,6 +133,8 @@ void scanone_mr(int n_ind, int n_pos, int n_gen, int **Geno,
 
   for(i=0; i<n_pos; i++) {
 
+    R_CheckUserInterrupt(); /* check for ^C */
+
     /* genotyped individuals at this marker */
     for(j=0, this_n_ind=0; j<n_ind; j++) {
       if(Geno[i][j] > 0) {
