@@ -2,12 +2,23 @@
  * 
  * scanone_np.c
  *
- * copyright (c) 2001, Karl W Broman, Johns Hopkins University
+ * copyright (c) 2001-6, Karl W Broman
  *
- * last modified Nov, 2001
+ * last modified Dec, 2006
  * first written Nov, 2001
  *
- * Licensed under the GNU General Public License version 2 (June, 1991)
+ *     This program is free software; you can redistribute it and/or
+ *     modify it under the terms of the GNU General Public License, as
+ *     published by the Free Software Foundation; either version 2 of
+ *     the License, or (at your option) any later version. 
+ * 
+ *     This program is distributed in the hope that it will be useful,
+ *     but without any warranty; without even the implied warranty of
+ *     merchantability or fitness for a particular purpose.  See the
+ *     GNU General Public License for more details.
+ * 
+ *     A copy of the GNU General Public License is available at
+ *     http://www.r-project.org/Licenses/
  *
  * C functions for the R/qtl package
  *
@@ -25,6 +36,7 @@
 #include <Rmath.h>
 #include <R_ext/PrtUtil.h>
 #include <R_ext/Applic.h>
+#include <R_ext/Utils.h>
 #include "util.h"
 #include "scanone_np.h"
 
@@ -80,6 +92,8 @@ void scanone_np(int n_ind, int n_pos, int n_gen,
 
   for(i=0; i<n_pos; i++) {
 
+    R_CheckUserInterrupt(); /* check for ^C */
+
     result[i] = 0.0;
     for(k=0; k<n_gen; k++) {
       sp = ssp = sr = 0.0;
